@@ -21,48 +21,45 @@
 
 from __future__ import print_function
 
-from opsramp.base import ApiWrapper
+from opsramp.base import ApiWrapper, Helpers
 
 
 class Rba(ApiWrapper):
     def __init__(self, parent):
         super(Rba, self).__init__(parent.api, 'rba')
 
-    def category(self, uuid):
-        return Category(self, uuid)
+    def categories(self):
+        return Categories(self)
 
-    def get_categories(self):
-        return self.api.get('/categories')
 
-    def create_category(self, name, parent_uuid=None):
+class Categories(ApiWrapper):
+    def __init__(self, parent):
+        super(Categories, self).__init__(parent.api, 'categories')
+
+    # Creates a new category with optional parent.
+    def create(self, name, parent_uuid=None):
         jjj = {'name': name}
         if parent_uuid:
             jjj['parent'] = parent_uuid
-        return self.api.post('/categories', json=jjj)
+        return self.api.post(json=jjj)
+
+    def category(self, uuid):
+        return Category(self, uuid)
 
 
 class Category(ApiWrapper):
     def __init__(self, parent, uuid):
-        super(Category, self).__init__(parent.api, 'categories/%s' % uuid)
+        super(Category, self).__init__(parent.api, '%s/scripts' % uuid)
 
-    def script(self, uuid):
-        return Script(self, uuid)
+    # Creates a script in this category
+    def create(self, definition):
+        return self.api.post(json=definition)
 
-    def get_scripts(self):
-        return self.api.get('/scripts')
-
-    def create_script(self, script_definition):
-        return self.api.post('/scripts', json=script_definition)
-
-
-class Script(ApiWrapper):
-    def __init__(self, parent, uuid):
-        super(Script, self).__init__(parent.api, 'scripts/%s' % uuid)
-
-    # A helper function for use with mkparameter & mkscript.
+    # A helper function for use with mkParameter & mkScript.
     @staticmethod
-    def mkattachment(name, payload):
+    def mkAttachment(name, payload):
         assert name
+        assert payload
         return {
             'name': name,
             'file': payload
@@ -70,7 +67,7 @@ class Script(ApiWrapper):
 
     # Returns a Python dict that defines one parameter of a script.
     @staticmethod
-    def mkparameter(name, description, datatype,
+    def mkParameter(name, description, datatype,
                     optional=False, default=None):
         assert name
         assert description
@@ -89,7 +86,9 @@ class Script(ApiWrapper):
     # for use with Category.create_script() it also asserts that
     # certain rules are being complied with in the script definition.
     @staticmethod
-    def mkscript(name, description, platforms, execution_type, payload,
+    def mkScript(name, description, platforms, execution_type,
+                 payload=None,
+                 payload_file=None,
                  parameters=[],
                  script_name=None,
                  install_timeout=0,
@@ -99,6 +98,14 @@ class Script(ApiWrapper):
                  service_name=None,
                  output_directory=None,
                  output_file=None):
+        assert name
+        assert description
+        assert platforms
+        assert execution_type
+        if payload_file:
+            assert not payload
+            payload = Helpers.b64encode_payload(payload_file)
+        assert payload
         if execution_type not in ('DOWNLOAD', 'EXE', 'MSI'):
             assert not output_directory
             assert not output_file
@@ -106,8 +113,9 @@ class Script(ApiWrapper):
             payload_key = 'command'
             payload_value = payload
         else:
+            assert script_name
             payload_key = 'attachment'
-            payload_value = Script.mkattachment(script_name, payload)
+            payload_value = Category.mkAttachment(script_name, payload)
 
         # fields that are always present.
         retval = {
